Feature

Enum Feature 

pub enum Feature {
Show 21 variants _64b, compat, sse, sse2, sse3, ssse3, sse41, sse42, bmi1, bmi2, lzcnt, popcnt, avx, avx2, avx512f, avx512vl, avx512dq, avx512bitalg, avx512vbmi, cmpxchg16b, fma,
}
A CPU feature.

IA-32e mode is the typical mode of operation for modern 64-bit x86 processors. It consists of two sub-modes:

  • 64-bit mode: uses the full 64-bit address space
  • compatibility mode: allows use of legacy 32-bit code

Other features listed here should match the CPUID Feature Flags column of the instruction tables of the x64 reference manual.

This is generated from the dsl::Feature enumeration defined in the meta crate; see for_each_feature.

Variants



_64b



compat



sse



sse2



sse3



ssse3



sse41



sse42



bmi1



bmi2



lzcnt



popcnt



avx



avx2



avx512f



avx512vl



avx512dq



avx512bitalg



avx512vbmi



cmpxchg16b



fma